@@ -1,6 +1,6 @@
 package MooseX::ConfigCascade;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moose::Role;
 use MooseX::ConfigCascade::Util;
@@ -116,17 +116,17 @@ MooseX::ConfigCascade - Set initial accessor values of your whole Moose-based pr
 
 In my opinion getting values from some kind of centralised config to attributes in nested objects is problematic. There are several modules available which load config into accessors, but in one way or another these all involve telling each specific object about the config, and changing the code of each package to accommodate that config.
 
-MooseX::ConfigCascade attempts to solve not only the issue of loading from a centralised config file, but also delivery of config values to objects within objects, nested to arbitrary depth, without the need for any added code within the modules. Specify a config file once (perhaps at the top of your script), and from then on any object you create can enjoy having its attributes loaded directly from the config.
+L<MooseX::ConfigCascade> attempts to solve not only the issue of loading from a centralised config file, but also delivery of config values to objects within objects, nested to arbitrary depth, without the need for any added code within the modules. Specify a config file once (perhaps at the top of your script), and from then on any object you create can enjoy having its attributes loaded directly from the config.
 
 If you don't specify a config file, the object will just initialise with the default values it was going to take otherwise. Nor is there any requirement for how many attributes you choose to put in your config. Load lots of them, or just one. Any that don't get a definition in your config file will load package default values as before.
 
-MooseX::ConfigCascade also allows CSS style cascading of config declarations. In the example in the synopsis, the attributes 'company_name' and 'slogan' (belonging to the My::Logo package) were assigned values 3 times in the configuration file. The most specific definition in the config that matches the object structure wins. So in the example, if My::Logo is initialised on its own, then it will get the value provided in the 'My::Logo' directive in the config file. If the My::Logo object is initialised in the accessor 'logo' in My::Label however, the more specific My::Label definition wins.
+L<MooseX::ConfigCascade> also allows CSS style cascading of config declarations. In the example in the synopsis, the attributes 'company_name' and 'slogan' (belonging to the My::Logo package) were assigned values 3 times in the configuration file. The most specific definition in the config that matches the object structure wins. So in the example, if My::Logo is initialised on its own, then it will get the value provided in the C<My::Logo> directive in the config file. If the C<My::Logo> object is initialised in the accessor C<logo> in C<My::Label> however, the more specific C<My::Label> definition wins.
 
 This module was born out of frustration with the paradox of trying to make sure config remains centralised while also keeping objects independent of one another. A tempting and easy way to deal with config is simply to pass a reference around to all objects that need it in your project. This works great, but it has the side effect of effectively tying all your objects to a specific heirarchy. 
 
 If you pull out one of your objects to use somewhere else, it's still expecting that same config reference. If you coded with portability in mind originally, then you might have added code to say 'use the config if its available, but use defaults if not'. However there's also the issue that your config data structure still needs to be in the same format - and that format may not be appropriate any more.
 
-MooseX::ConfigCascade addresses this last point because it always expects a file format that matches the package structure of your project.
+L<MooseX::ConfigCascade> addresses this last point because it always expects a file format that matches the package structure of your project.
 
 
 =head2 CAVEATS
@@ -137,30 +137,30 @@ MooseX::ConfigCascade addresses this last point because it always expects a file
 
 at the top of each module you want to take part. MooseX::ConfigCascade will not traverse into modules which don't adopt this role (as much a safety feature as anything else).
 
-1. MooseX::ConfigCascade will populate 'ro' and 'rw' accessors of types 'HashRef', 'ArrayRef', 'Bool' or 'Str', and any subtypes of these types (including 'Num' and 'Int' which are subtypes of 'Str' in Moose). It won't populate anything else. 
+1. MooseX::ConfigCascade will populate C<ro> and C<rw> accessors of types C<HashRef>, C<ArrayRef>, C<Bool> or C<Str>, and any subtypes of these types (including C<Num> and C<Int> which are subtypes of C<Str> in Moose). It won't populate anything else. 
 
 2. The magic is performed at object instantiation only.
 
-3. Any affected attributes defined as 'lazy' will have their laziness thrown out of the window - ie they will get the values in the config straight away whatever. (This should be irrelevant. Attributes are generally 'lazy' when they depend on other attributes, which is not the case if the value comes from the config file)
+3. Any affected attributes defined as C<lazy> will have their laziness thrown out of the window - ie they will get the values in the config straight away whatever. (This should be irrelevant. Attributes are generally C<lazy> when they depend on other attributes, which is not the case if the value comes from the config file)
 
-3. MooseX::ConfigCascade will traverse objects within objects provided they follow the one object per accessor rule. In other words it will not traverse collections of objects, such as 'HashRef[My::Object]' or 'ArrayRef[My::Object]'. (I looked into this, but decided it would be complex and would bloat the module).
+3. L<MooseX::ConfigCascade> will traverse objects within objects provided they follow the one object per accessor rule. In other words it will not traverse collections of objects, such as C<HashRef[My::Object]> or C<ArrayRef[My::Object]>. (I looked into this, but decided it would be complex and would bloat the module).
 
-4. MooseX::ConfigCascade is compatible with inheritance and roles - ie it can populate objects that are comprised of locally defined attributes and attributes inherited from parent classes, or attributes absorbed from adopted roles. However, it will NOT see or populate class attributes using L<MooseX::ClassAttribute>.
+4. L<MooseX::ConfigCascade> is compatible with inheritance and roles - ie it can populate objects that are comprised of locally defined attributes and attributes inherited from parent classes, or attributes absorbed from adopted roles. However, it will NOT see or populate class attributes using L<MooseX::ClassAttribute>.
 
-5. Whilst some effort has gone into testing this module, it is presented at an early stage of development and without much real-world testing. It has not been tested at all with most MooseX:: extensions and there is the possibility of conflict. If you discover problems please let me know.
+5. Whilst some effort has gone into testing this module, it is presented at an early stage of development and without much real-world testing. It has not been tested at all with most C<MooseX::> extensions and there is the possibility of conflict. If you discover problems please let me know.
 
 
 =head1 ATTRIBUTE LOADING
 
 =head2 File Format
 
-Off the shelf MooseX::ConfigCascade supports text files containing YAML or JSON. If the file starts with a dash (-) it is assumed to be YAML and will be read in using the L<YAML> CPAN module. If it begins with an opening curly bracket ({) then it is assumed to be JSON and will be read in using the L<JSON> CPAN module. By default, if the file starts any other way an error is returned. (I decided against including XML as standard as it would have required too many options.)
+Off the shelf L<MooseX::ConfigCascade> supports text files containing YAML or JSON. If the file starts with a dash (-) it is assumed to be YAML and will be read in using the L<YAML> CPAN module. If it begins with an opening curly bracket ({) then it is assumed to be JSON and will be read in using the L<JSON> CPAN module. By default, if the file starts any other way an error is returned. (I decided against including XML as standard as it would have required too many options.)
 
-However MooseX::ConfigCascade can potentially support any file format, but you must create and pass in your own parsing subroutine. See the ->parser method description in L<MooseX::ConfigCascade::Util>.
+However L<MooseX::ConfigCascade> can potentially support any file format, but you must create and pass in your own parsing subroutine. See the C<parser> method description in L<MooseX::ConfigCascade::Util>.
 
 =head2 Basic Attribute Assignment
 
-The file needs to be organised so that when the parser pulls the data into a hashref, the keys of the hash are the names of packages. When a new object is created, MooseX::ConfigCascade looks for the name of the package being created in the config file. If the package matches, it looks at the value corresponding to the package name key, where again it expects to find a hashref, this time containing ( attribute name, value) pairs. ie the overall config hashref now looks like:
+The file needs to be organised so that when the parser pulls the data into a hashref, the keys of the hash are the names of packages. When a new object is created, MooseX::ConfigCascade looks for the name of the package being created in the config file. If the package matches, it looks at the value corresponding to the package name key, where again it expects to find a hashref, this time containing ( attribute name, value) pairs. ie the overall config hashref might look something like this:
 
     {
         'First::Package' => {
@@ -175,7 +175,7 @@ The file needs to be organised so that when the parser pulls the data into a has
 
     }
 
-For reference, C<First::Package> might look something like this:
+C<First::Package> might look something like this:
 
     package First::Package;
 
@@ -201,7 +201,7 @@ For reference, C<First::Package> might look something like this:
     ); 
 
 
-The config structure above will work provided those four attributes are all of type 'Str'. But lets say we change First::Package so fp_attribute1 is a HashRef. From now we will assume you understand that packages can have attributes not specified in the config, and leave these out. For simplicity we'll also just focus on the one package. So C<First::Package> looks something like this:
+The config structure above will work provided those four attributes are all of type C<Str>. But lets say we change C<First::Package> so C<fp_attribute1> is a C<HashRef>. From now we will assume you understand that packages can have attributes not specified in the config, and leave these out. For simplicity we'll also just focus on the one package. So now C<First::Package> looks something like this:
 
     package First::Package;
 
@@ -241,7 +241,7 @@ and our config hashref should look something like:
 
     }
 
-If we had made fp_attribute1 an arrayref instead, then the config would need to look like:
+If we had made C<fp_attribute1> an C<ArrayRef> instead, then the config would need to look like:
 
    {
         'First::Package' => {
@@ -339,7 +339,7 @@ or if you wanted to use JSON:
         }
     }
 
-). When you create a new C<Box::Package> object, MooseX::ConfigCascade looks for the attribute named C<contents>. It sees that C<contents> contains an object, and traverses into the object. It then attempts to assign the hash 
+). When you create a new C<Box::Package> object, L<MooseX::ConfigCascade> looks for the attribute named C<contents>. It sees that C<contents> contains an object, and traverses into the object. It then attempts to assign the hash 
 
     {
 
@@ -363,9 +363,9 @@ Some things to note:
 
 3. If the attribute is specified as C<lazy> it will be pulled out of its lazy state and evaluated
 
-4. You may have noticed that assignment to attributes of type 'HashRef' is done using a hashref, and assignment to attributes in nested objects also uses a hashref. It is true that (in the current release) there is no distinction in the config file between attributes of type 'HashRef' and attributes containing objects. You could swap out your attribute containing an object for an attribute containing a HashRef and you would not get an error. It's up to you to make sure what you are delivering makes sense.
+4. You may have noticed that assignment to attributes of type C<HashRef> is done using a hashref, and assignment to attributes in nested objects also uses a hashref. It is true that (in the current release) there is no distinction in the config file between attributes of type C<HashRef> and attributes containing objects. You could swap out your attribute containing an object for an attribute containing a C<HashRef> and you would not get an error. It's up to you to make sure what you are delivering makes sense.
 
-5. Further to point 4, nor does the config file distinguish the type of object contained in the attribute. Change C<Contents::Package> to C<DifferentContents::Package> and the attribute assignment will still work (provided C<DifferentContents::Package> also has a C<stuff> attribute of type 'Str'.)
+5. Further to point 4, nor does the config file distinguish the type of object contained in the attribute. Change C<Contents::Package> to C<DifferentContents::Package> and the attribute assignment will still work (provided C<DifferentContents::Package> also has a C<stuff> attribute of type C<Str>.)
 
 6. If we had defined an attribute as a collection of objects, either by using C<HashRef[Some::Package]> or C<ArrayRef[Some::Package]> - for example:
 
@@ -376,7 +376,7 @@ Some things to note:
         }
     });
 
-then there is *no way* to assign values to the objects in the collection from the config. MooseX::ConfigCascade does NOT provide this functionality.
+then there is B<no way> to assign values to the objects in the collection from the config. MooseX::ConfigCascade does NOT provide this functionality.
 
 
 =head2 Cascading
@@ -404,7 +404,7 @@ Suppose we add that declaration mentioned in point 1 above, so our config hashre
 
     }
 
-but note that we also added C<(from box)> and C<(from contents)> to distinguish where the values are going to get loaded from. 
+but note that I also added C<(from box)> and C<(from contents)> to distinguish where the values are going to get loaded from. 
 
 Now if we create a C<Box::Package> object and examine the C<stuff> attribute inside C<contents> we will find:
 
@@ -477,7 +477,7 @@ C<Pets::BigDog> and C<Pets::SmallDog> both inherit the C<size> attribute from C<
 
 =head2 Loading Order
 
-Loading of attributes happens after C<BUILD>. This means if you use C<BUILD> to assign values to attributes, MooseX::ConfigCascade may overwrite those values (depending if there are values for those attributes specified in the config). If you want to be sure of overwriting the config values, then you could do this using
+Loading of attributes happens after C<BUILD>. This means if you use C<BUILD> to assign values to attributes, L<MooseX::ConfigCascade> may overwrite those values (depending if there are values for those attributes specified in the config). If you want to be sure of overwriting the config values, then you could do this using
 
     after 'BUILD' => sub {
         # overwrite the attributes here
@@ -493,7 +493,7 @@ You can also make sure objects get individual values by specifying them in the o
 
 =head1 METHODS
 
-Remember not to 'use MooseX::ConfigCascade'. It's a role, so you should state:
+Remember B<not> to C<use MooseX::ConfigCascade>. It's a role, so you should state:
 
     with 'MooseX::ConfigCascade';
 
@@ -501,7 +501,7 @@ When you do this, a single new attribute is added to your class:
 
 =head2 cascade_util
 
-This is a L<MooseX::ConfigCascade::Util> object, which has 3 utility methods. So once you added the MooseX::ConfigCascade role to your package, you can do:
+This is a L<MooseX::ConfigCascade::Util> object, which has 3 utility methods. So once you added the L<MooseX::ConfigCascade> role to your package, you can do:
 
     my $object = My::Package->new;
 
@@ -509,7 +509,7 @@ This is a L<MooseX::ConfigCascade::Util> object, which has 3 utility methods. So
     $object->cascade_util->path;     # the path to the config file (if any)
     $object->cascade_util->parser;   # the code ref to the subroutine which parses your config file
 
-Note C<conf>, C<path> and C<parser> are all B<class attributes> of MooseX::ConfigCascade::Util. That means it is intended that you generally set them by calling the class directly:
+Note C<conf>, C<path> and C<parser> are all B<class attributes> of L<MooseX::ConfigCascade::Util>. That means it is intended that you generally set them by calling the class directly:
 
     MooseX::ConfigCascade::Util->path( '/path/to/config.yaml' );
 
@@ -519,7 +519,7 @@ so you may not ever need to use C<cascade_util> at all. However, you may find it
 
     $whatever_object->cascade_util->conf;
 
-See the documentation for MooseX::ConfigCascade::Util for information about these methods.
+See the documentation for L<MooseX::ConfigCascade::Util> for information about these methods.
 
 
 =head1 SEE ALSO
